Crate kcr_opentelemetry_io

Crate kcr_opentelemetry_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the opentelemetry.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

opentelemetry.io/v1alpha1

  • Instrumentation
  • OpAMPBridge
  • OpenTelemetryCollector

opentelemetry.io/v1beta1

  • OpenTelemetryCollector

Modules

v1alpha1
v1beta1