This crate contains kube-rs compatible bindings for Kubernetes custom resources for the opentelemetry.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
opentelemetry.io/v1alpha1
InstrumentationOpAMPBridgeOpenTelemetryCollector
opentelemetry.io/v1beta1
OpenTelemetryCollector